@@ -23,7 +23,14 @@ local ffi_intp_type = ffi.typeof("int *")
 local ffi_int_size = ffi.sizeof("int")
 
 
-ngx.worker = new_tab(0, 4)
+local is_not_windows = jit.os ~= "Windows"
+
+if is_not_windows then
+    ngx.worker = new_tab(0, 5)
+
+else
+    ngx.worker = new_tab(0, 4)
+end
 
 
 if subsystem == "http" then
@@ -38,13 +45,6 @@ if subsystem == "http" then
     ngx_lua_ffi_worker_pid = C.ngx_http_lua_ffi_worker_pid
     ngx_lua_ffi_worker_count = C.ngx_http_lua_ffi_worker_count
     ngx_lua_ffi_worker_exiting = C.ngx_http_lua_ffi_worker_exiting
-    if jit.os ~= "Windows" then
-        ffi.cdef[[
-        int ngx_http_lua_ffi_worker_pids(int *pids, size_t *pids_len);
-        ]]
-
-        ngx_lua_ffi_worker_pids = C.ngx_http_lua_ffi_worker_pids
-    end
 
 elseif subsystem == "stream" then
     ffi.cdef[[
@@ -59,13 +59,6 @@ elseif subsystem == "stream" then
     ngx_lua_ffi_worker_count = C.ngx_stream_lua_ffi_worker_count
     ngx_lua_ffi_worker_exiting = C.ngx_stream_lua_ffi_worker_exiting
 
-    if jit.os ~= "Windows" then
-        ffi.cdef[[
-        int ngx_stream_lua_ffi_worker_pids(int *pids, size_t *pids_len);
-        ]]
-
-        ngx_lua_ffi_worker_pids = C.ngx_stream_lua_ffi_worker_pids
-    end
 end
 
 
@@ -79,16 +72,36 @@ function ngx.worker.pid()
 end
 
 
-if jit.os ~= "Windows" then
+if is_not_windows then
+    if subsystem == "http" then
+        require "resty.core.phase"  -- for ngx.get_phase
+
+        ffi.cdef[[
+        int ngx_http_lua_ffi_worker_pids(int *pids, size_t *pids_len);
+        ]]
+
+        ngx_lua_ffi_worker_pids = C.ngx_http_lua_ffi_worker_pids
+
+    elseif subsystem == "stream" then
+        ffi.cdef[[
+        int ngx_stream_lua_ffi_worker_pids(int *pids, size_t *pids_len);
+        ]]
+
+        ngx_lua_ffi_worker_pids = C.ngx_stream_lua_ffi_worker_pids
+    end
+
+    local ngx_phase = ngx.get_phase
+
     function ngx.worker.pids()
-        if ngx.get_phase() == "init" or ngx.get_phase() == "init_worker" then
+        local phase = ngx_phase()
+        if phase == "init" or phase == "init_worker" then
             return nil, "API disabled in the current context"
         end
 
         local pids = {}
         local size_ptr = get_size_ptr()
         -- the old and the new workers coexist during reloading
-        local worker_cnt = ngx.worker.count() * 4
+        local worker_cnt = ngx_lua_ffi_worker_count() * 4
         if worker_cnt == 0 then
             return pids
         end
@@ -100,13 +113,15 @@ if jit.os ~= "Windows" then
 
         if res == 0 then
             for i = 1, tonumber(size_ptr[0]) do
-                pids[i] = intp_buf[i-1]
+                pids[i] = intp_buf[i - 1]
             end
         end
+
         return pids
     end
 end
 
+
 function ngx.worker.id()
     local id = ngx_lua_ffi_worker_id()
     if id < 0 then
